code_emit

Function code_emit 

pub fn code_emit(particle: CodeValue)
Emit a particle to the host runtime.

The particle must be an object with a _class string field. If code_module_set_emit has not been called, this is a no-op.

Thread-safe: may be called from any thread.