read_str

Function read_str 

pub unsafe fn read_str<'a>(v: &CodeValue) -> &'a str
Read a string from an CodeValue, returning "" if the tag is wrong or the pointer is null.

Safety

The string pointer inside v must be valid if v.tag == CODE_TAG_STRING.