pub unsafe fn read_field<'a>(v: &CodeValue, name: &str) -> Option<&'a CodeValue>Expand description
Look up a field by name inside an Object CodeValue.
Returns None if the value is not an object or the field is not found.
Safety
The fields pointer and field name pointers must be valid.